require('dotenv').config();
const app = require('template')();
const path = require('path');
const engineLodash = require('engine-lodash');
const {
  compose,
  snakeToCamel,
  getComponentName,
  toDashCase,
} = require('../utils');
const config = require('../lib/config');

const PACKAGE_PATH = process.env.MODE === 'development' ? process.cwd() : path.dirname(require.main.filename);
const TMPL_PATH = config.get('tmplPath') || `${PACKAGE_PATH}/tmpl`;

const STYLES_FILE_NAMING_TYPE = config.get('cssFileName');

app.engine('tmpl', engineLodash);
app.create('pages');

app.page('welcome.tmpl', { path: 'welcome.tmpl', content: 'Hello, <%= name %>!' });

const getFileContent = async ({ name, tmplFileName }) => {
  console.log('PACKAGE_PATH', PACKAGE_PATH);
  console.log('config.get("tmplPath")', config.get('tmplPath'));
  console.log('PACKAGE_PATH with tmpl', `${PACKAGE_PATH}/tmpl`);
  const tmplPath = `${TMPL_PATH}/${tmplFileName}`;
  const props = {
    componentName: compose(getComponentName, snakeToCamel)(name),
    stylesName: STYLES_FILE_NAMING_TYPE === 'component' ? `${toDashCase(name)}.css` : 'styles.css',
  };

  app.page(tmplPath, { path: tmplPath });

  const page = app.pages.get(tmplPath);

  const { content } = await page.render(props, (err, res) => {
    if (err) return err;
    return res.content;
  });

  return content;
};

module.exports = {
  getFileContent,
};
